/****************************************************************************/
/*                                                                          */
/*  Function:  Decide whether an input value is a prime number.             */
/*             Print the numbers it is divisible by if it is not prime.     */
/*                                                                          */
/*  Description:  One way to find out whether a number is a prime number is */
/*      by dividing the input value by prime numbers.  This would require   */
/*      the generation and storage of a list of prime numbers.  Another     */
/*      semi-brute force way is to simply divide the number by all the      */
/*      integers that are smaller up to the square root of the number.      */
/*      Since we want ALL the factors, we divide up to the (number / 2).    */
/*                                                                          */
/*  Author:   Bary W Pollack                                                */
/*                                                                          */
/*  File:     Primes.cpp                                                    */
/*                                                                          */
/*  Date:     09/24/97      Revised:                                        */
/*                                                                          */
/*  Input:    Any integer.  The sentinel value is any non-positive value.   */
/*                                                                          */
/****************************************************************************/

#include <iostream.h>

#define YES  (1)
#define NO   (0)

int main (void)
{
    int divisor,          /* Divisor - a counter            */
        limit,            /* loop limit                     */
        prime,            /* Flag: 1-number is prime else 0 */
        value;            /* Input value                    */

    cout << "Prime number determinator" << endl
         << endl
         << "Enter a whole number each time.  Enter a non-positive "
         << "number to stop."
         << endl << endl;

    /************************************************************************/
    /*      Main loop to check to see if the value is prime                 */
    /************************************************************************/

    cout << "Please enter the value: ";
    cin  >> value;
    while (value > 0)
    {
        prime = YES;                             /* assume prime            */
        limit = value / 2;                       /* trial limit             */

        /********************************************************************/
        /*          Check for prime                                         */
        /********************************************************************/

        for (divisor = 2; divisor <= limit; divisor++)
        {
            if ((value % divisor) == 0)          /* prime?                  */
            {
                if (prime)                       /* message printed yet?    */
                {                                /* if not                  */
                    cout << value << " is divisible by " << divisor;
                    prime = NO;                  /* show number isn't prime */
                }
                else
                    cout << ", " << divisor;
            }
        }  // End of for loop
        if (prime)
            cout << value << " is a prime number";  /* prime?               */

        /********************************************************************/
        /*          Get next value                                          */
        /********************************************************************/

        cout << endl
             << "Please enter another number  (or non-pos to end): ";
        cin  >> value;
        }  // End of while loop

    cout << endl
         << "Goodbye!" << endl
         << endl;

    return 0;
}  // End of main


/****************************************************************************

Prime number determinator

Enter a whole number each time.  Enter a non-positive number to stop.

Please enter the value: 2
2 is a prime number
Please enter another number  (or non-pos to end): 3
3 is a prime number
Please enter another number  (or non-pos to end): 4
4 is divisible by 2
Please enter another number  (or non-pos to end): 9
9 is divisible by 3
Please enter another number  (or non-pos to end): 12
12 is divisible by 2, 3, 4, 6
Please enter another number  (or non-pos to end): 100
100 is divisible by 2, 4, 5, 10, 20, 25, 50
Please enter another number  (or non-pos to end): 0

Goodbye!

 ****************************************************************************/

